Crate linux_syscalls

Crate linux_syscalls 

Available on (32-bit and ARM, or 32-bit and little-endian and x86, or 64-bit and AArch64, or 64-bit and little-endian and x86-64) and (Android or Linux), or Linux and (32-bit and big-endian and PowerPC, or 32-bit and little-endian and RISC-V RV32, or 32-bit and little-endian and x86-64, or 32-bit and MIPS, or 64-bit and big-endian and s390x, or 64-bit and little-endian and LoongArch64, or 64-bit and little-endian and RISC-V RV64, or 64-bit and MIPS-64, or 64-bit and PowerPC64) only.

Modules

env
A collection of environment informations useful to detect features used in syscalls.

Macros

kversionNon-bare
A macro to create/query kernel version.
raw_syscall
Make a syscall and returns a usize
syscall
Make a syscall and returns a Result<usize, Errno>

Structs

Errno
Error number representation.

Enums

Sysno
List of system call numbers.

Functions

initNon-bare
Initialize the environment for the library. It’s recommended to call it before anything else in the main function.
init_from_args⚠bare
Initialize library from arguments count and arguments list (int argc, char **argv). It’s recommended to call it before anything else in the main function.
init_from_auxv⚠bare
Initialize library from auxv pointer. It’s recommended to call it before anything else in the main function.
init_from_environ⚠bare
Initialize library from the environment list pointer (char **envp). It’s recommended to call it before anything else in the main function.
raw_syscall0⚠Non-outline_syscalls
Make a raw system call with 0 arguments.
raw_syscall0_readonly⚠Non-outline_syscalls
Make a raw system call with 0 arguments. Like the non _readonly version but you declare that syscall does not mutate any memory.
raw_syscall1⚠Non-outline_syscalls
Make a raw system call with 1 argument.
raw_syscall2⚠Non-outline_syscalls
Make a raw system call with 2 arguments.
raw_syscall3⚠Non-outline_syscalls
Make a raw system call with 3 arguments.
raw_syscall4⚠Non-outline_syscalls
Make a raw system call with 4 arguments.
raw_syscall5⚠Non-outline_syscalls
Make a raw system call with 5 arguments.
raw_syscall6⚠Non-outline_syscalls
Make a raw system call with 6 arguments.
raw_syscall1_readonly⚠Non-outline_syscalls
Make a raw system call with 1 argument. Like the non _readonly version but you declare that syscall does not mutate any memory.
raw_syscall2_readonly⚠Non-outline_syscalls
Make a raw system call with 2 arguments. Like the non _readonly version but you declare that syscall does not mutate any memory.
raw_syscall3_readonly⚠Non-outline_syscalls
Make a raw system call with 3 arguments. Like the non _readonly version but you declare that syscall does not mutate any memory.
raw_syscall4_readonly⚠Non-outline_syscalls
Make a raw system call with 4 arguments. Like the non _readonly version but you declare that syscall does not mutate any memory.
raw_syscall5_readonly⚠Non-outline_syscalls
Make a raw system call with 5 arguments. Like the non _readonly version but you declare that syscall does not mutate any memory.
raw_syscall6_readonly⚠Non-outline_syscalls
Make a raw system call with 6 arguments. Like the non _readonly version but you declare that syscall does not mutate any memory.
syscall0⚠Non-outline_syscalls
Make a raw system call with 0 arguments.
syscall0_readonly⚠Non-outline_syscalls
Make a raw system call with 0 arguments. Like the non _readonly version but you declare that syscall does not mutate any memory.
syscall1⚠Non-outline_syscalls
Make a raw system call with 1 argument.
syscall2⚠Non-outline_syscalls
Make a raw system call with 2 arguments.
syscall3⚠Non-outline_syscalls
Make a raw system call with 3 arguments.
syscall4⚠Non-outline_syscalls
Make a raw system call with 4 arguments.
syscall5⚠Non-outline_syscalls
Make a raw system call with 5 arguments.
syscall6⚠Non-outline_syscalls
Make a raw system call with 6 arguments.
syscall1_noreturn⚠Non-outline_syscalls
Make a raw system call with 7 arguments. It’s assured that it will not return.
syscall1_readonly⚠Non-outline_syscalls
Make a raw system call with 1 argument. Like the non _readonly version but you declare that syscall does not mutate any memory.
syscall2_readonly⚠Non-outline_syscalls
Make a raw system call with 2 arguments. Like the non _readonly version but you declare that syscall does not mutate any memory.
syscall3_readonly⚠Non-outline_syscalls
Make a raw system call with 3 arguments. Like the non _readonly version but you declare that syscall does not mutate any memory.
syscall4_readonly⚠Non-outline_syscalls
Make a raw system call with 4 arguments. Like the non _readonly version but you declare that syscall does not mutate any memory.
syscall5_readonly⚠Non-outline_syscalls
Make a raw system call with 5 arguments. Like the non _readonly version but you declare that syscall does not mutate any memory.
syscall6_readonly⚠Non-outline_syscalls
Make a raw system call with 6 arguments. Like the non _readonly version but you declare that syscall does not mutate any memory.