Available on (32-bit and ARM, or 32-bit and little-endian and x86, or 64-bit and AArch64, or 64-bit and little-endian and x86-64) and (Android or Linux), or Linux and (32-bit and big-endian and PowerPC, or 32-bit and little-endian and RISC-V RV32, or 32-bit and little-endian and x86-64, or 32-bit and MIPS, or 64-bit and big-endian and s390x, or 64-bit and little-endian and LoongArch64, or 64-bit and little-endian and RISC-V RV64, or 64-bit and MIPS-64, or 64-bit and PowerPC64) only.
Modules
- env
- A collection of environment informations useful to detect features used in syscalls.
Macros
- kversion
Non- bare - A macro to create/query kernel version.
- raw_
syscall - Make a syscall and returns a
usize - syscall
- Make a syscall and returns a
Result<usize, Errno>
Structs
- Errno
- Error number representation.
Enums
- Sysno
- List of system call numbers.
Functions
- init
Non- bare - Initialize the environment for the library. It’s recommended to call it before anything else in the main function.
- init_
from_ ⚠args bare - Initialize library from arguments count and arguments list (
int argc, char **argv). It’s recommended to call it before anything else in the main function. - init_
from_ ⚠auxv bare - Initialize library from auxv pointer. It’s recommended to call it before anything else in the main function.
- init_
from_ ⚠environ bare - Initialize library from the environment list pointer (
char **envp). It’s recommended to call it before anything else in the main function. - raw_
syscall0 ⚠Non- outline_syscalls - Make a raw system call with 0 arguments.
- raw_
syscall0_ ⚠readonly Non- outline_syscalls - Make a raw system call with 0 arguments.
Like the non
_readonlyversion but you declare that syscall does not mutate any memory. - raw_
syscall1 ⚠Non- outline_syscalls - Make a raw system call with 1 argument.
- raw_
syscall2 ⚠Non- outline_syscalls - Make a raw system call with 2 arguments.
- raw_
syscall3 ⚠Non- outline_syscalls - Make a raw system call with 3 arguments.
- raw_
syscall4 ⚠Non- outline_syscalls - Make a raw system call with 4 arguments.
- raw_
syscall5 ⚠Non- outline_syscalls - Make a raw system call with 5 arguments.
- raw_
syscall6 ⚠Non- outline_syscalls - Make a raw system call with 6 arguments.
- raw_
syscall1_ ⚠readonly Non- outline_syscalls - Make a raw system call with 1 argument.
Like the non
_readonlyversion but you declare that syscall does not mutate any memory. - raw_
syscall2_ ⚠readonly Non- outline_syscalls - Make a raw system call with 2 arguments.
Like the non
_readonlyversion but you declare that syscall does not mutate any memory. - raw_
syscall3_ ⚠readonly Non- outline_syscalls - Make a raw system call with 3 arguments.
Like the non
_readonlyversion but you declare that syscall does not mutate any memory. - raw_
syscall4_ ⚠readonly Non- outline_syscalls - Make a raw system call with 4 arguments.
Like the non
_readonlyversion but you declare that syscall does not mutate any memory. - raw_
syscall5_ ⚠readonly Non- outline_syscalls - Make a raw system call with 5 arguments.
Like the non
_readonlyversion but you declare that syscall does not mutate any memory. - raw_
syscall6_ ⚠readonly Non- outline_syscalls - Make a raw system call with 6 arguments.
Like the non
_readonlyversion but you declare that syscall does not mutate any memory. - syscall0⚠
Non- outline_syscalls - Make a raw system call with 0 arguments.
- syscall0_
readonly ⚠Non- outline_syscalls - Make a raw system call with 0 arguments.
Like the non
_readonlyversion but you declare that syscall does not mutate any memory. - syscall1⚠
Non- outline_syscalls - Make a raw system call with 1 argument.
- syscall2⚠
Non- outline_syscalls - Make a raw system call with 2 arguments.
- syscall3⚠
Non- outline_syscalls - Make a raw system call with 3 arguments.
- syscall4⚠
Non- outline_syscalls - Make a raw system call with 4 arguments.
- syscall5⚠
Non- outline_syscalls - Make a raw system call with 5 arguments.
- syscall6⚠
Non- outline_syscalls - Make a raw system call with 6 arguments.
- syscall1_
noreturn ⚠Non- outline_syscalls - Make a raw system call with 7 arguments. It’s assured that it will not return.
- syscall1_
readonly ⚠Non- outline_syscalls - Make a raw system call with 1 argument.
Like the non
_readonlyversion but you declare that syscall does not mutate any memory. - syscall2_
readonly ⚠Non- outline_syscalls - Make a raw system call with 2 arguments.
Like the non
_readonlyversion but you declare that syscall does not mutate any memory. - syscall3_
readonly ⚠Non- outline_syscalls - Make a raw system call with 3 arguments.
Like the non
_readonlyversion but you declare that syscall does not mutate any memory. - syscall4_
readonly ⚠Non- outline_syscalls - Make a raw system call with 4 arguments.
Like the non
_readonlyversion but you declare that syscall does not mutate any memory. - syscall5_
readonly ⚠Non- outline_syscalls - Make a raw system call with 5 arguments.
Like the non
_readonlyversion but you declare that syscall does not mutate any memory. - syscall6_
readonly ⚠Non- outline_syscalls - Make a raw system call with 6 arguments.
Like the non
_readonlyversion but you declare that syscall does not mutate any memory.