Module env

Module env 

Available on (32-bit and ARM, or 32-bit and little-endian and x86, or 64-bit and AArch64, or 64-bit and little-endian and x86-64) and (Android or Linux), or Linux and (32-bit and big-endian and PowerPC, or 32-bit and little-endian and RISC-V RV32, or 32-bit and little-endian and x86-64, or 32-bit and MIPS, or 64-bit and big-endian and s390x, or 64-bit and little-endian and LoongArch64, or 64-bit and little-endian and RISC-V RV64, or 64-bit and MIPS-64, or 64-bit and PowerPC64) only.
A collection of environment informations useful to detect features used in syscalls.

Re-exports

pub use self::kernel::utsname;
pub use self::kernel::Version;
pub use self::vdso::Vdso;

Modules

aux
kernel
vdso

Functions

getauxvalNon-bare
Returns values from the auxiliary vector, a mechanism that the kernel’s ELF binary loader uses to pass certain information to user space when a program is executed.
kernel_versionNon-bare
Returns a cached kernel version.
unameNon-bare
Returns a cached crate::env::kernel::utsname. It do not use uname syscall.
unchecked_getauxval
Returns values from the auxiliary vector, a mechanism that the kernel’s ELF binary loader uses to pass certain information to user space when a program is executed.
unchecked_kernel_version
Returns a cached kernel version.
unchecked_uname
Returns a cached crate::env::kernel::utsname. It do not use uname syscall.
unchecked_vdso
Returns the cached crate::env::vdso::Vdso for the current process.
vdsoNon-bare
Returns cached crate::env::vdso::Vdso for the current process.